Bumbling is a python module that reads exif data from image files and renames them accordingly. 

Bumbling relies on the "exiftool" command-line tool which is available here: https://exiftool.org/ 

The source code is available at this github repository: https://github.com/JonathanRoth13/bumbling.git

Documentation is available at: https://jonathanroth13.com/projects/bumbling/
